<?php
$TRANSLATIONS = array(
"Calendar" => "ਕੈਲੰਡ",
"Sunday" => "ਐਤਵਾਰ",
"Monday" => "ਸੋਮਵਾਰ",
"Tuesday" => "ਮੰਗਲਵਾਰ",
"Wednesday" => "ਬੁੱਧਵਾਰ",
"Thursday" => "ਵੀਰਵਾਰ",
"Friday" => "ਸ਼ੁੱਕਰਵਾਰ",
"Saturday" => "ਸ਼ਨਿੱਚਰਵਾਰ",
"January" => "ਜਨਵਰੀ",
"February" => "ਫਰਵਰੀ",
"March" => "ਮਾਰਚ",
"April" => "ਅਪਰੈ",
"May" => "ਮਈ",
"June" => "ਜੂਨ",
"July" => "ਜੁਲਾਈ",
"August" => "ਅਗਸਤ",
"September" => "ਸਤੰਬ",
"October" => "ਅਕਤੂਬਰ",
"November" => "ਨਵੰਬ",
"December" => "ਦਸੰਬਰ",
"Download" => "ਡਾਊਨਲੋਡ",
"Delete" => "ਹਟਾਓ",
"Share" => "ਸਾਂਝਾ ਕਰੋ"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
